@@ -65,10 +65,19 @@ class Loads():
 
         if self.load_condition == 'slamming':
             psl = self.__calculate_poly_value(0)
+            return max(press, psl)
         else:
-            psl = 0
-
-        return max(press, psl)
+            return press
+    def get_report_string(self):
+        return [     'Name of load: ' + self.name_of_load,
+                     'Polynominal (x^3): '+  str(self.poly_third) ,
+                     'Polynominal (x^2): '+  str(self.poly_second) ,
+                     'Polynominal (x):   '+  str(self.poly_first) ,
+                     'Constant (C):      '+  str(self.poly_const) ,
+                     'Load condition:    '+  str(self.load_condition) ,
+                     'Limit state        ' +  str(self.limit_state) ,
+                     'Is external?       '+  str(self.is_external) ,
+                     'Static draft:      '+  str(self.static_draft)]
 
     def __calculate_poly_value(self, variable):
         '''
@@ -144,7 +153,7 @@ class Tanks():
         self.acc_static = tank_dict['acc']['static']
         self.acc_dyn_loaded = tank_dict['acc']['dyn_loaded']
         self.acc_dyn_ballast = tank_dict['acc']['dyn_ballast']
-        self.all_types = ['crude_oil', 'diesel', 'slop', 'ballast']
+        self.all_types = ['crude_oil', 'diesel', 'slop', 'fresh water', 'ballast']
 
     def __str__(self):
         '''
@@ -312,7 +321,7 @@ class Tanks():
         self.tank_options = ['crude_oil', 'diesel', 'slop', 'ballast']
         :return:
         '''
-        try: return self.content in self.all_types[0:3]
+        try: return self.content in self.all_types[0:4]
         except AttributeError: return False
 
     def is_ballast_condition(self):
@@ -320,7 +329,7 @@ class Tanks():
         Check to see if the tank shall be in cluded in loaded condition.
         :return:
         '''
-        try: return self.content == self.all_types[3]
+        try: return self.content == self.all_types[4]
         except AttributeError: return False
 
     def is_tank_test_condition(self):
