@@ -29,6 +29,7 @@ class CreateFatigueWindow():
             self.pressure_coords = self.get_pressure_point_coord_from_two_points(coords[0], coords[1])
             self._initial_structure_obj = app._line_to_struc[app._active_line][0]
             self.load_objects = app._line_to_struc[app._active_line][3]
+
             self.comp_objects = [app._tank_dict['comp'+str(comp_i)] for comp_i in
                                  app.get_compartments_for_line(app._active_line)]
             self._initial_fatigue_obj = app._line_to_struc[self.active_line][2]
@@ -182,6 +183,8 @@ class CreateFatigueWindow():
 
         count = 1
         for load in self.load_objects:
+            if load == None:
+                continue
             press = []
             if load.get_limit_state() == 'FLS':
                 tk.Label(self._frame, text=str(count)+'. '+load.get_name(), font='Verdana 8')\
@@ -199,7 +202,8 @@ class CreateFatigueWindow():
                 count += 1
         press = []
         for comp in self.comp_objects:
-
+            if comp == None:
+                continue
             tk.Label(self._frame, text=str(count) + '. ' +str(comp.get_name()), font='Verdana 8') \
                 .place(x=start_x + 5 * dx, y=start_y + (5 + count) * dy)
 
