@@ -56,29 +56,35 @@ def one_load_combination(line_name_obj, coord, defined_loads, load_condition,
         return [None, ' ']
 
 def helper_dnva_dnvb(line_name_obj, coord, defined_loads, load_condition,
-                         defined_tanks, comb_name, acc, load_factors_all, print_to_file = False):
+                         defined_tanks, comb_name, acc, load_factors_all):
 
     # calculate the defined loads
-    calc_load, load_print = [], ['',]
+    calc_load, load_print, prt_conditions = [], ['',], []
     line_name = line_name_obj[0]
     structure_type = line_name_obj[1].get_structure_type()
     if print_it:
         #load_print.append('Load calculation for '+line_name_obj[0] + ' ' + comb_name+ ' ' + load_condition)
         pass
-    static_pressure,dynamic_pressure = 0,0
+
+    # if print_line != None and line_name == print_line:
+    #     print('Load calculation for '+line_name_obj[0] + ' ' + comb_name+ ' ' + load_condition)
 
     if len(defined_loads) !=  0:
         for load in defined_loads :
+            if comb_name+load_condition not in prt_conditions:
+                load_print.append("Loads for condition: " + load_condition + ' - ' + comb_name +' ' + '\n')
+                prt_conditions.append(comb_name+load_condition)
             if load != None:
 
                 load_factors = load_factors_all[(comb_name, line_name, load.get_name())]
-                if print_it:
-                    if load_factors[0].get() != 0:
-                        load_print.append('LOAD NAME: '+' '+ comb_name+ ' '+ line_name+' '+ load.get_name()+'\n')
-                if load_factors[1].get() != 0:
-                    if load_factors[0].get() != 0:
-                        load_print.append('LOAD NAME: '+' '+ comb_name+ ' '+ line_name+' '+ load.get_name()+'\n')
+                # if print_it:
+                #     if load_factors[0].get() != 0:
+                #         load_print.append('LOAD NAME: '+' '+ comb_name+ ' '+ line_name+' '+ load.get_name()+'\n')
+                # if load_factors[1].get() != 0:
+                #     if load_factors[0].get() != 0:
+                #         load_print.append('LOAD NAME: '+' '+ comb_name+ ' '+ line_name+' '+ load.get_name()+'\n')
                 # USE GET() (static,dyn, on/off)
+
                 if load_condition == load.get_load_condition():
                     static_pressure = (load_factors[2].get())*(load_factors[0].get())\
                                       *load.get_calculated_pressure(coord, acc[0],structure_type)
@@ -99,13 +105,16 @@ def helper_dnva_dnvb(line_name_obj, coord, defined_loads, load_condition,
                                  str(load_factors[1].get())+'*'+\
                                  str(round(load.get_calculated_pressure(coord, acc[1],structure_type),1))+ ' = '+ \
                                  str(round(dynamic_pressure,1))+'\n')
+
                     calc_load.append(static_pressure+dynamic_pressure)
 
     # calculate the tank loads
 
     if len(defined_tanks) != 0:
         temp_tank = {}
-
+        if comb_name + load_condition not in prt_conditions:
+            load_print.append("Loads for condition: " + load_condition + ' - ' + comb_name + ' ' + '\n')
+            prt_conditions.append(comb_name + load_condition)
         for tank_name_obj in defined_tanks:
             temp_tank[tank_name_obj[0]] = 0
 
@@ -122,7 +131,8 @@ def helper_dnva_dnvb(line_name_obj, coord, defined_loads, load_condition,
                                    +tank_name_obj[1].get_overpressure()*overpress_lf[1]
 
                 temp_tank[tank_name_obj[0]] = static_pressure + dynamic_pressure# .append((static_pressure + dynamic_pressure))
-                if print_it:
+                if print_it and tank_name_obj[0]+load_condition not in prt_conditions:
+                    prt_conditions.append(tank_name_obj[0]+load_condition)
                     #load_print.append('load (TANK) calculation for load condition:'+ load_condition+ ' - Tank is: '+ tank_name_obj[0]+'\n')
                     #load_print.append('load factors : '+ str(load_factors[0].get())+str(load_factors[1].get())+str(load_factors[2].get())+'\n')
                     load_print.append('\n' + tank_name_obj[0] + ' - static: '+ str(load_factors[2].get())+ '*'+ str(load_factors[0].get()) + '*'+\
@@ -135,14 +145,19 @@ def helper_dnva_dnvb(line_name_obj, coord, defined_loads, load_condition,
 
         if len(defined_loads) == 0:
             line_tank_pressure_calc = max([pressure for pressure in temp_tank.values()])
+
+            #print('line_tank_pressure_calc', line_tank_pressure_calc)
             highest_dnv_tank_pressure  = tank_name_obj[1].get_tank_dnv_minimum_pressure(load_factors[0].get(),
                                                                                         load_factors[1].get())
+            #print('highest_dnv_tank_pressure', highest_dnv_tank_pressure)
             line_dnv_tank_pressure = tank_name_obj[1].get_line_pressure_from_max_pressure(highest_dnv_tank_pressure,
                                                                                           coord)
+            #print('line_dnv_tank_pressure', line_dnv_tank_pressure)
             # if line_name_obj[0] == 'line29':
             #     print('Tank load to append is max( ',highest_tank_pressure_calc,highest_dnv_tank_pressure,')')
             highest_tank_pressure = max(line_tank_pressure_calc,line_dnv_tank_pressure)
             calc_load.append(-highest_tank_pressure if highest_tank_pressure else 0)
+            load_print.append('\nDNVGL-OS-C101 4.3.7 and 4.3.8 (Tank pressures) = '+ str(highest_tank_pressure)+'\n')
         else:
             pass
     if print_it:
@@ -243,7 +258,7 @@ def helper_manual(line_name, comb_name,load_factors_all):
                           str(load_factors[2].get()) + ' = '+ str(man_press) +'\n')
     return [man_press, load_print]
 
-def helper_read_section_file(files, obj = None, to_json = False, to_csv = False):
+def helper_read_section_file(files, obj = None, to_json = False, to_csv = None):
     ''' Read a xml file. '''
     import json
     from xml.dom import minidom
@@ -305,8 +320,6 @@ def helper_read_section_file(files, obj = None, to_json = False, to_csv = False)
             with open(file, 'r') as csv_file:
                 csv_reader = csv.reader(csv_file, delimiter=',')
                 for idx, section in enumerate(csv_reader):
-
-
                     to_return[str(idx)] = {'stf_web_height': [float(section[0]), 'm'],
                                            'stf_web_thk': [float(section[1]),'m'],
                                            'stf_flange_width': [float(section[2]),'m'],
@@ -317,8 +330,8 @@ def helper_read_section_file(files, obj = None, to_json = False, to_csv = False)
         with open('sections.json', 'w') as file:
             json.dump(to_return, file)
 
-    if to_csv:
-        with open('sections.csv', 'w', newline = '') as file:
+    if to_csv is not None:
+        with open(to_csv, 'w', newline = '') as file:
             section_writer = csv.writer(file)
             for line in return_csv:
                 section_writer.writerow(line)
@@ -379,8 +392,9 @@ def add_new_section(section_list, new_section):
 if __name__ == '__main__':
     import ANYstructure.example_data as ex
     from pathlib import Path
-    file = Path('C:/Users/nmm000756/Documents/GitHub/ANYstructure/ANYstructure/sections.json')
-    all_returned = helper_read_section_file(file.name)
+    #file = Path('C:\\Program Files\\DNVGL\\GeniE V8.0-21\\Libraries\\tbar.xml')
+    all_returned = helper_read_section_file('C:\\Program Files\\DNVGL\\GeniE V8.0-21\\Libraries\\tbar.xml', to_csv='tbar.csv')
 
     import random
-    print(random.choice(all_returned))
+
+    print(all_returned)
