@@ -67,6 +67,13 @@ class CreateLoadWindow():
         self._main_canvas = tk.Canvas(self._frame,width=self._canvas_dim[0], height=self._canvas_dim[1],
                                      background='azure', relief = 'groove', borderwidth=2)
         self._main_canvas.place(relx=0.32,rely=0.25)
+        self._global_shrink = 1
+        base_canvas_dim = [1000, 720]  # do not modify this, sets the "orignal" canvas dimensions.
+        self._canvas_dim = [int(base_canvas_dim[0] *self._global_shrink),
+                           int(base_canvas_dim[1] *self._global_shrink)]
+        self._canvas_base_origo = [50, base_canvas_dim[1] - 50] # 50 bottom left location of the canvas, (0,0)
+        self._canvas_draw_origo = list(self._canvas_base_origo)
+        self._previous_drag_mouse = list(self._canvas_draw_origo)
 
         # --- slider (used to zoom) ----
         self._slider = tk.Scale(self._frame,from_=60,to = 1, command = self.slider_used,
@@ -111,7 +118,7 @@ class CreateLoadWindow():
         self._new_slamming_pressure_name.set('slamming')
 
         ent_w = 15
-        ent_dyn_load_name = tk.Entry(self._frame, textvariable=self._new_dynamic_load_name, width=ent_w)
+        ent_dyn_load_name = tk.Entry(self._frame, textvariable=self._new_dynamic_load_name, width=ent_w*2)
         ent_load_poly_third = tk.Entry(self._frame, textvariable=self._new_load_poly_third, width=ent_w)
         ent_load_poly_second = tk.Entry(self._frame, textvariable=self._new_load_poly_second, width=ent_w)
         ent_load_poly_first = tk.Entry(self._frame, textvariable=self._new_load_poly_first,width=ent_w)
@@ -186,11 +193,20 @@ class CreateLoadWindow():
                                        relief = 'groove', borderwidth=2)
         self._load_obj_box.place(x=10, y=start_y + 3 * delta_y)
         self._load_obj_box.bind('<<ListboxSelect>>', self.left_click_load_box)
+        loads_scrollbar = tk.Scrollbar(self._frame)
+        loads_scrollbar.config(command = self._load_obj_box.yview)
+        loads_scrollbar.place(x=140, y=start_y + 3 * delta_y)
+        self._load_obj_box.config(yscrollcommand=loads_scrollbar.set)
         tk.Label(self._frame, text = 'Select to see assosiated lines: ').place(x=10, y=start_y +  2*delta_y)
 
         # --- showing the lines applied to the load above ---
         self._load_obj_lines_box = tk.Listbox(self._frame, height = 15, selectmode = listbox_select, bg = 'azure',
                                              relief = 'groove', borderwidth=2)
+        lines_scrollbar = tk.Scrollbar(self._frame)
+        lines_scrollbar.config(command = self._load_obj_lines_box.yview)
+        lines_scrollbar.place(x=330, y=start_y+ 3 * delta_y)
+        self._load_obj_lines_box.config(yscrollcommand=lines_scrollbar.set)
+
         self._load_obj_lines_box.place(x=200, y=start_y+ 3 * delta_y)
         self._load_obj_lines_box.bind('<<ListboxSelect>>', self.left_click_load_box)
         tk.Label(self._frame, text = '-->',font="Verdana 8 bold").place(x=160, y= load_vert_start + 15 * delta_y )
@@ -212,7 +228,7 @@ class CreateLoadWindow():
         # --- delete a created load ---
         tk.Button(self._frame, text="Delete selected load",command=self.delete_load,
                   font='Verdana 9 bold', fg='yellow', bg = 'red' )\
-            .place(x=270, y=start_y + 1.5 * delta_y)
+            .place(x=10, y=start_y + 12 * delta_y)
 
         # --- updating the imported loads from main window ---
         if len(self._load_objects) > 0:
@@ -247,12 +263,12 @@ class CreateLoadWindow():
 
         # grid for the canavs
 
-        self._main_canvas.create_line(self._canvas_origo[0], 0, self._canvas_origo[0], self._canvas_dim[1],
+        self._main_canvas.create_line(self._canvas_draw_origo[0], 0, self._canvas_draw_origo[0], self._canvas_dim[1],
                                      stipple='gray50')
-        self._main_canvas.create_line(0, self._canvas_origo[1], self._canvas_dim[0], self._canvas_origo[1],
+        self._main_canvas.create_line(0, self._canvas_draw_origo[1], self._canvas_dim[0], self._canvas_draw_origo[1],
                                      stipple='gray50')
-        self._main_canvas.create_text(self._canvas_origo[0] - 30 ,
-                                     self._canvas_origo[1] + 20 , text='(0,0)',
+        self._main_canvas.create_text(self._canvas_draw_origo[0] - 30 ,
+                                     self._canvas_draw_origo[1] + 20 , text='(0,0)',
                                      font='Text 10')
         self._main_canvas.create_text([800 ,50],
                                      text='Mouse left click:  select lines to loads\n'
@@ -270,19 +286,29 @@ class CreateLoadWindow():
                 vector = [coord2[0] - coord1[0], coord2[1] - coord1[1]]
                 # drawing a bold line if it is selected
                 if line in self._active_lines:
-                    if load_selected and line in self._load_obj_lines_box.get(0,'end'):
-                        color = 'red'
-                    self._main_canvas.create_line(coord1, coord2, width=6, fill=color)
+                    self._main_canvas.create_line(coord1, coord2, width=6, fill='orange')
                     self._main_canvas.create_text(coord1[0] + vector[0] / 2 + 5, coord1[1] + vector[1] / 2 + 10,
                                                  text='Line ' + str(get_num(line)), font='Verdand 10 bold',
                                                  fill='red')
                 else:
-                    if load_selected and line in self._load_obj_lines_box.get(0,'end'):
-                        color = 'red'
                     self._main_canvas.create_line(coord1, coord2, width=3, fill=color)
                     self._main_canvas.create_text(coord1[0] - 20 + vector[0] / 2 + 5, coord1[1] + vector[1] / 2 + 10,
                                                  text='line' + str(get_num(line)), font="Text 8", fill='black')
 
+    def button_2_click_and_drag(self,event):
+
+        self._canvas_draw_origo = (self._canvas_draw_origo[0]-(self._previous_drag_mouse[0]-event.x),
+                                  self._canvas_draw_origo[1]-(self._previous_drag_mouse[1]-event.y))
+
+        self._previous_drag_mouse = (event.x,event.y)
+        self.draw_canvas()
+
+    def mouse_scroll(self,event):
+        self._canvas_scale +=  event.delta/50
+        self._canvas_scale = 0 if self._canvas_scale < 0 else self._canvas_scale
+
+        self.draw_canvas()
+
     def get_loads(self):
         '''
         Returning loads
@@ -303,9 +329,9 @@ class CreateLoadWindow():
             if load != 'manual':# and (combination, line, load) not in self._load_comb_dict.keys():
                 #print(combination, line, load)
                 self._load_comb_dict[(combination, line, load)] = [tk.DoubleVar(), tk.DoubleVar(), tk.IntVar()]
-                if combination is not 'tanktest':
+                if combination != 'tanktest':
                     if self._load_objects[load][0].is_static():
-                        if self._load_objects[load][0].get_limit_state() is 'FLS':
+                        if self._load_objects[load][0].get_limit_state() == 'FLS':
                             self._load_comb_dict[(combination, line, load)][0].set(0)
                         elif self._load_objects[load][0].is_tank_test():
                             self._load_comb_dict[(combination, line, load)][0].set(0)
@@ -317,7 +343,7 @@ class CreateLoadWindow():
 
                     else:
                         self._load_comb_dict[(combination, line, load)][0].set(0)
-                        if self._load_objects[load][0].get_limit_state() is 'FLS':
+                        if self._load_objects[load][0].get_limit_state() == 'FLS':
                             self._load_comb_dict[(combination, line, load)][1].set(1)
                         else:
                             self._load_comb_dict[(combination, line, load)][1].set(factors[2])
@@ -348,9 +374,12 @@ class CreateLoadWindow():
 
         variables = ['poly_third','poly_second', 'poly_first', 'poly_const', 'load_condition',
                      'man_press', 'static_draft', 'name_of_load', 'limit_state', 'structure_types']
+        existing_load = None
         if not slamming_load:
             name_of_load = self._new_dynamic_load_name.get()
             if name_of_load in self._load_objects.keys():
+                # Existing load
+                existing_load = copy.deepcopy(self._load_objects[name_of_load])
                 self._load_objects.pop(name_of_load)
                 self._load_obj_box.delete(0,'end')
                 for load in self._load_objects.keys():
@@ -363,6 +392,7 @@ class CreateLoadWindow():
         else:
             name_of_load = self._new_slamming_pressure_name.get()
             if name_of_load in self._load_objects.keys():
+                existing_load = copy.deepcopy(self._load_objects[name_of_load])
                 self._load_objects.pop(name_of_load)
                 self._load_obj_box.delete(0, 'end')
                 for load in self._load_objects.keys():
@@ -378,7 +408,7 @@ class CreateLoadWindow():
             current_load_dict[item] = values[count_i]
             count_i += 1
 
-        self._load_objects[name_of_load] = [Loads(current_load_dict),[]]
+        self._load_objects[name_of_load] = [Loads(current_load_dict),[] if existing_load is None else existing_load[1]]
         self._load_options.append(name_of_load)
         self._ent_assosiate_load.destroy()
         self._ent_assosiate_load = tk.OptionMenu(self._frame, self._new_assisiate_load, *tuple(self._load_options))
@@ -406,8 +436,10 @@ class CreateLoadWindow():
                      'structure_type', 'man_press', 'static_draft','name_of_load']
 
         name_of_load = self._new_static_load_name.get()
+        existing_load = None
 
         if name_of_load in self._load_objects.keys():
+            existing_load = copy.deepcopy(self._load_objects[name_of_load])
             self._load_objects.pop(name_of_load)
             self._load_obj_box.delete(0,'end')
             for load in self._load_objects.keys():
@@ -423,7 +455,7 @@ class CreateLoadWindow():
             current_load_dict[item] = values[count_i]
             count_i += 1
 
-        self._load_objects[name_of_load] = [Loads(current_load_dict),[]]
+        self._load_objects[name_of_load] = [Loads(current_load_dict),[] if existing_load is None else existing_load[1]]
 
         self._load_options.append(name_of_load)
         self._ent_assosiate_load.destroy()
@@ -442,9 +474,10 @@ class CreateLoadWindow():
 
         current_load = self._new_assisiate_load.get()
         if current_load != '':
+            self._load_objects[current_load][1] = []
             for line in self._active_lines:
-                if line not in self._load_objects[current_load][1]:
-                    self._load_objects[current_load][1].append(line)
+                #if line not in self._load_objects[current_load][1]:
+                self._load_objects[current_load][1].append(line)
         else:
             mess = tk.messagebox.showwarning('Select load',message='Select a load to apply to the selected lines.',
                                              type='ok')
@@ -489,8 +522,8 @@ class CreateLoadWindow():
         Returning the canvas coordinates of the point. This value will change with slider.
         '''
 
-        point_coord_x = self._canvas_origo[0] + self._point_dict[point_no][0]* self._canvas_scale
-        point_coord_y = self._canvas_origo[1] - self._point_dict[point_no][1]* self._canvas_scale
+        point_coord_x = self._canvas_draw_origo[0] + self._point_dict[point_no][0] * self._canvas_scale
+        point_coord_y = self._canvas_draw_origo[1] - self._point_dict[point_no][1] * self._canvas_scale
 
         return [point_coord_x, point_coord_y]
 
@@ -500,12 +533,15 @@ class CreateLoadWindow():
         :return:
         '''
         self._main_canvas.bind('<Button-1>', self.left_click)
+        self._main_canvas.bind('<Button-2>', self.button_2_click)
         self._main_canvas.bind('<Button-3>', self.right_click)
         self._load_obj_box.bind('<Button-1>', self.left_click_load_box)
         self._frame.bind('<Shift_L>', self.shift_pressed)
         self._frame.bind('<Shift_R>', self.shift_pressed)
         self._frame.bind('<Control_L>', self.ctrl_pressed)
         self._frame.bind('<Control_R>', self.ctrl_pressed)
+        self._main_canvas.bind("<MouseWheel>", self.mouse_scroll)
+        self._main_canvas.bind("<B2-Motion>", self.button_2_click_and_drag)
 
     def shift_pressed(self,event=None):
         '''
@@ -522,12 +558,20 @@ class CreateLoadWindow():
         '''
         self._add_to_lines = False
 
+    def button_2_click(self, event):
+        '''
+        Event when right click.
+        :param evnet:
+        :return:
+        '''
+        self._previous_drag_mouse = [event.x, event.y]
+
     def left_click(self, event):
         '''
         When clicking the right button, this method is called.
         method is referenced in
         '''
-
+        self._previous_drag_mouse = [event.x, event.y]
         click_x = self._main_canvas.winfo_pointerx() - self._main_canvas.winfo_rootx()
         click_y = self._main_canvas.winfo_pointery() - self._main_canvas.winfo_rooty()
         stop = False
@@ -567,6 +611,7 @@ class CreateLoadWindow():
         :param evnet:
         :return:
         '''
+        self._previous_drag_mouse = [event.x, event.y]
         self._active_lines = []
         self._main_canvas.delete('all')
         self.draw_canvas()
