@@ -21,12 +21,12 @@ import csv
 
 def run_optmizataion(initial_structure_obj=None, min_var=None, max_var=None, lateral_pressure=None,
                      deltas=None, algorithm='anysmart', trials=30000, side='p',
-                     const_chk = (True,True,True,True,True,True, True),
+                     const_chk = (True,True,True,True,True,True, True, False),
                      pso_options = (100,0.5,0.5,0.5,100,1e-8,1e-8), is_geometric=False, fatigue_obj = None ,
                      fat_press_ext_int = None,
                      min_max_span = (2,6), tot_len = None, frame_height = 2.5, frame_distance = None,
                      slamming_press = 0, predefined_stiffener_iter = None, processes = None, use_weight_filter = True,
-                     load_pre = False, opt_girder_prop = None):
+                     load_pre = False, opt_girder_prop = None, puls_sheet = None, puls_acceptance = 0.87):
     '''
     The optimazation is initiated here. It is called from optimize_window.
     :param initial_structure_obj:
@@ -47,8 +47,8 @@ def run_optmizataion(initial_structure_obj=None, min_var=None, max_var=None, lat
         fat_dict = None if fatigue_obj is None else fatigue_obj.get_fatigue_properties()
 
     if use_weight_filter:
-        if is_geometric or algorithm is 'pso':
 
+        if is_geometric or algorithm == 'pso':
             init_filter_weight = float('inf')
         else:
 
@@ -61,13 +61,15 @@ def run_optmizataion(initial_structure_obj=None, min_var=None, max_var=None, lat
                                                     len(predefined_stiffener_iter),
                                                     fat_dict=fat_dict,
                                                     fat_press=None if fat_press_ext_int is None else fat_press_ext_int,
-                                                    predefined_stiffener_iter = predefined_stiffener_iter)
+                                                    predefined_stiffener_iter = predefined_stiffener_iter,
+                                                    slamming_press=slamming_press)
 
     if algorithm == 'anysmart' and not is_geometric:
         to_return = any_smart_loop(min_var, max_var, deltas, initial_structure_obj, lateral_pressure,
                                    init_filter_weight, side=side, const_chk=const_chk, fat_dict=fat_dict,
                                    fat_press=fat_press_ext_int,slamming_press=slamming_press,
-                                   predefiened_stiffener_iter=predefined_stiffener_iter)
+                                   predefiened_stiffener_iter=predefined_stiffener_iter, puls_sheet = puls_sheet,
+                                   puls_acceptance = puls_acceptance)
         return to_return
     elif algorithm == 'anysmart' and is_geometric:
         return geometric_summary_search(min_var= min_var, max_var=max_var, deltas= deltas,
@@ -99,7 +101,7 @@ def run_optmizataion(initial_structure_obj=None, min_var=None, max_var=None, lat
         return None
 
 def any_optimize_loop(min_var,max_var,deltas,initial_structure_obj,lateral_pressure, init_filter = float('inf'),
-                      side='p',const_chk=(True,True,True,True,True), fat_dict = None, fat_press = None,
+                      side='p',const_chk=(True,True,True,True,True,False), fat_dict = None, fat_press = None,
                       slamming_press = 0):
     '''
     Calulating initial values.
@@ -148,7 +150,8 @@ def any_optimize_loop(min_var,max_var,deltas,initial_structure_obj,lateral_press
 
 def any_smart_loop(min_var,max_var,deltas,initial_structure_obj,lateral_pressure, init_filter = float('inf'),
                    side='p',const_chk=(True,True,True,True,True,True,True), fat_dict = None, fat_press = None,
-                   slamming_press = 0, predefiened_stiffener_iter = None, processes = None):
+                   slamming_press = 0, predefiened_stiffener_iter = None, processes = None,
+                   puls_sheet = None, puls_acceptance = 0.87):
     '''
     Trying to be smart
     :param min_var:
@@ -157,14 +160,6 @@ def any_smart_loop(min_var,max_var,deltas,initial_structure_obj,lateral_pressure
     :return:
     '''
 
-    # if predefiened_stiffener_iter is None:
-    #     structure_to_check = any_get_all_combs(min_var, max_var, deltas, init_weight=init_filter)
-    # else:
-    #     #structure_to_check = [obj.get_tuple() for obj in predefiened_stiffener_iter]
-    #     structure_to_check = any_get_all_combs(min_var, max_var, deltas, init_weight=init_filter,
-    #                                            predef_stiffeners=predefiened_stiffener_iter)
-    #     init_filter = get_initial_weight(initial_structure_obj, lateral_pressure, min_var, max_var, deltas, 10000,
-    #                                      fat_dict, fat_press, predefiened_stiffener_iter)
 
     if predefiened_stiffener_iter is None:
         structure_to_check = any_get_all_combs(min_var, max_var, deltas)
@@ -174,7 +169,8 @@ def any_smart_loop(min_var,max_var,deltas,initial_structure_obj,lateral_pressure
 
     main_result = get_filtered_results(structure_to_check, initial_structure_obj,lateral_pressure,
                                        init_filter_weight=init_filter, side=side,chk=const_chk, fat_dict=fat_dict,
-                                       fat_press=fat_press, slamming_press=slamming_press, processes=processes)
+                                       fat_press=fat_press, slamming_press=slamming_press, processes=processes,
+                                       puls_sheet = puls_sheet, puls_acceptance = puls_acceptance)
 
     main_iter = main_result[0]
     main_fail = main_result[1]
@@ -191,8 +187,13 @@ def any_smart_loop(min_var,max_var,deltas,initial_structure_obj,lateral_pressure
     if ass_var == None:
         return None, None, None, False, main_fail
 
-    new_struc_obj = create_new_structure_obj(initial_structure_obj,[item for item in ass_var])
-    new_calc_obj = create_new_calc_obj(initial_structure_obj,[item for item in ass_var])[0]
+    if len(ass_var) == 8:
+        ass_var = [round(item, 10) for item in ass_var[0:8]]
+    else:
+        ass_var = [round(item, 10) for item in ass_var[0:8]] + [ass_var[8]]
+
+    new_struc_obj = create_new_structure_obj(initial_structure_obj,ass_var)
+    new_calc_obj = create_new_calc_obj(initial_structure_obj,ass_var)[0]
 
     return new_struc_obj, new_calc_obj, fat_dict, True, main_fail
 
@@ -211,7 +212,6 @@ def any_smart_loop_geometric(min_var,max_var,deltas,initial_structure_obj,latera
         else:
             this_predefiened_objects = None
 
-
         opt_obj = any_smart_loop(min_var = min_var,max_var = max_var,deltas = deltas,initial_structure_obj = struc_obj,
                                  lateral_pressure = lat_press, init_filter = init_filter, side=side,
                                  const_chk=const_chk,
@@ -408,19 +408,20 @@ def geometric_summary_search(min_var=None,max_var=None,deltas = None, initial_st
                 min_var[0:6] += deltas/2
                 max_var[0:6] -= deltas/2
 
-            if algorithm is 'pso':
+            if algorithm == 'pso':
                 opt_objects = particle_search_geometric(min_var=min_var,max_var=max_var,deltas=deltas,
                                                         initial_structure_obj=working_objects[no_of_fractions],
                                                         lateral_pressure=working_lateral[no_of_fractions],
                                                         init_filter = init_filter,side=side,const_chk=const_chk,
                                                         pso_options=pso_options, fat_obj = fat_obj,
                                                         fat_press = fat_press)
-            elif algorithm is 'anysmart':
+            elif algorithm == 'anysmart':
                 if load_pre:
                     import pickle
                     with open('geo_opt_2.pickle', 'rb') as file:
                         opt_objects = pickle.load(file)[no_of_fractions][1]
                 else:
+
                     opt_objects = any_smart_loop_geometric(min_var=min_var,max_var=max_var,deltas=deltas,
                                                            initial_structure_obj=working_objects[no_of_fractions],
                                                            lateral_pressure=working_lateral[no_of_fractions],
@@ -496,15 +497,38 @@ def any_find_min_weight_var(var):
     return min(map(calc_weight))
 
 
-def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True,True, True, True, True),
-                        fat_dict = None, fat_press = None, slamming_press = 0, print_result = False):
+def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True,True, True, True, True, False),
+                        fat_dict = None, fat_press = None, slamming_press = 0, PULSrun: calc.PULSpanel = None,
+                        print_result = False):
     '''
     Checking all constraints defined.
+
+        iter_var = ((item,init_stuc_obj,lat_press,init_filter_weight,side,chk,fat_dict,fat_press,slamming_press, PULSrun)
+                for item in iterable_all)
     :param x:
     :return:
     '''
-    all_checks = [0,0,0,0,0,0,0,0]
+    all_checks = [0,0,0,0,0,0,0,0,0]
+
+    calc_object = create_new_calc_obj(obj, x, fat_dict)
+
+    # PULS buckling check
+    if chk[7] and PULSrun is not None:
+        x_id = x_to_string(x)
+        if calc_object[0].get_puls_method() == 'buckling':
+            puls_uf = PULSrun.get_puls_line_results(x_id)["Buckling strength"]["Actual usage Factor"][0]
+        elif calc_object[0].get_puls_method() == 'ultimate':
+            puls_uf = PULSrun.get_puls_line_results(x_id)["Ultimate capacity"]["Actual usage Factor"][0]
+        if type(puls_uf) == str:
+            return False, 'PULS', x, all_checks
+        all_checks[8] = puls_uf/PULSrun.puls_acceptance
+        if puls_uf/PULSrun.puls_acceptance >= 1:
+            if print_result:
+                print('PULS', calc_object[0].get_one_line_string(), False)
+            return False, 'PULS', x, all_checks
+
     this_weight = calc_weight(x)
+
     if this_weight > init_weight:
         weigt_frac = this_weight / init_weight
         if print_result:
@@ -514,19 +538,18 @@ def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True
         all_checks[0] = weigt_frac
         return False, 'Weight filter', x, all_checks
 
-    calc_object = create_new_calc_obj(obj, x, fat_dict)
-
     # Section modulus
     if chk[0]:
         section_modulus = min(calc_object[0].get_section_modulus())
         min_section_modulus = calc_object[0].get_dnv_min_section_modulus(lat_press)
-        section_frac = min_section_modulus / section_modulus
+        section_frac = section_modulus / min_section_modulus # TODO is this correct
         all_checks[1] = section_frac
         if not section_modulus > min_section_modulus :
             if print_result:
                 print('Section modulus',calc_object[0].get_one_line_string(), False)
             return False, 'Section modulus', x, all_checks
 
+
     # Local stiffener buckling
     if chk[6]:
         buckling_local =  calc_object[0].buckling_local_stiffener()
@@ -538,7 +561,7 @@ def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True
 
     # Buckling
     if chk[3]:
-        buckling_results = calc_object[0].calculate_buckling_all(design_lat_press=lat_press, checked_side=side)
+        buckling_results = calc_object[0].calculate_buckling_all(design_lat_press=lat_press, checked_side=side)[0:5]
         all_checks[3] = max(buckling_results)
         if not all([uf<=1 for uf in buckling_results]):
             if print_result:
@@ -568,7 +591,8 @@ def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True
             return False, 'Shear area', x,  all_checks
 
     # Fatigue
-    if chk[4] and fat_dict is not None:
+    if chk[4] and fat_dict is not None and fat_press is not None:
+
         fatigue_uf = calc_object[1].get_total_damage(ext_press=fat_press[0],
                                                      int_press=fat_press[1])*calc_object[1].get_dff()
         all_checks[6] = fatigue_uf
@@ -578,6 +602,7 @@ def any_constraints_all(x,obj,lat_press,init_weight,side='p',chk=(True,True,True
             return False, 'Fatigue', x, all_checks
 
     # Slamming
+
     if chk[5] and slamming_press != 0:
         slam_check = calc_object[0].check_all_slamming(slamming_press)
         all_checks[7] = slam_check[1]
@@ -614,9 +639,10 @@ def any_constraints_all_number(x,*args):
     if not calc_object[0].buckling_local_stiffener():
         return -1
     # Buckling
+
     if chk[3]:
         if not all([uf<=1 for uf in calc_object[0].calculate_buckling_all(design_lat_press=lat_press,
-                                                                          checked_side=side)]):
+                                                                          checked_side=side)[0:5]]):
             return -1
     #Minimum plate thickeness
     if chk[1]:
@@ -656,8 +682,9 @@ def create_new_calc_obj(init_obj,x, fat_dict=None):
     :param init_obj:
     :return:
     '''
+
     x_old = [init_obj.get_s(), init_obj.get_plate_thk(), init_obj.get_web_h() , init_obj.get_web_thk(),
-             init_obj.get_fl_w() ,init_obj.get_fl_thk(), init_obj.get_span(), init_obj.get_lg()]
+             init_obj.get_fl_w(),init_obj.get_fl_thk(), init_obj.get_span(), init_obj.get_lg()]
 
     sigma_y1_new = stress_scaling(init_obj.get_sigma_y1(), init_obj.get_plate_thk(), x[1])
     sigma_y2_new = stress_scaling(init_obj.get_sigma_y2(), init_obj.get_plate_thk(), x[1])
@@ -672,14 +699,21 @@ def create_new_calc_obj(init_obj,x, fat_dict=None):
         stf_type = init_obj.get_stiffener_type()
 
     main_dict = {'mat_yield': [init_obj.get_fy(), 'Pa'],'span': [init_obj.get_span(), 'm'],
-                                'spacing': [x[0], 'm'],'plate_thk': [x[1], 'm'],'stf_web_height':[ x[2], 'm'],
-                                'stf_web_thk': [x[3], 'm'],'stf_flange_width': [x[4], 'm'],
-                                'stf_flange_thk': [x[5], 'm'],'structure_type': [init_obj.get_structure_type(), ''],
-                                'stf_type': [stf_type, ''],'sigma_y1': [sigma_y1_new, 'MPa'],
-                                'sigma_y2': [sigma_y2_new, 'MPa'],'sigma_x': [sigma_x_new, 'MPa'],
-                                'tau_xy': [tau_xy_new, 'MPa'],'plate_kpp': [init_obj.get_kpp(), ''],
-                                'stf_kps': [init_obj.get_kps(), ''],'stf_km1': [init_obj.get_km1(), ''],
-                                'stf_km2': [init_obj.get_km2(), ''],'stf_km3': [init_obj.get_km3(), '']}
+                 'spacing': [x[0], 'm'],'plate_thk': [x[1], 'm'],'stf_web_height':[ x[2], 'm'],
+                 'stf_web_thk': [x[3], 'm'],'stf_flange_width': [x[4], 'm'],
+                 'stf_flange_thk': [x[5], 'm'],'structure_type': [init_obj.get_structure_type(), ''],
+                 'stf_type': [stf_type, ''],'sigma_y1': [sigma_y1_new, 'MPa'],
+                 'sigma_y2': [sigma_y2_new, 'MPa'],'sigma_x': [sigma_x_new, 'MPa'],
+                 'tau_xy': [tau_xy_new, 'MPa'],'plate_kpp': [init_obj.get_kpp(), ''],
+                 'stf_kps': [init_obj.get_kps(), ''],'stf_km1': [init_obj.get_km1(), ''],
+                 'stf_km2': [init_obj.get_km2(), ''],'stf_km3': [init_obj.get_km3(), ''],
+                 'structure_types':[init_obj.get_structure_types(), ''],
+                 'zstar_optimization': [init_obj.get_z_opt(), ''],
+                 'puls buckling method':[init_obj.get_puls_method(),''],
+                 'puls boundary':[init_obj.get_puls_boundary(),''],
+                 'puls stiffener end':[init_obj.get_puls_stf_end(),''],
+                 'puls sp or up':[init_obj.get_puls_sp_or_up(),''],
+                 'puls up boundary':[init_obj.get_puls_up_boundary(),'']}
     if fat_dict == None:
         return calc.CalcScantlings(main_dict), None
     else:
@@ -705,14 +739,24 @@ def create_new_structure_obj(init_obj, x, fat_dict=None):
         stf_type = init_obj.get_stiffener_type()
 
     main_dict = {'mat_yield': [init_obj.get_fy(), 'Pa'], 'span': [init_obj.get_span(), 'm'],
-                               'spacing': [x[0], 'm'], 'plate_thk': [x[1], 'm'], 'stf_web_height': [x[2], 'm'],
-                               'stf_web_thk': [x[3], 'm'], 'stf_flange_width': [x[4], 'm'],
-                               'stf_flange_thk': [x[5], 'm'], 'structure_type': [init_obj.get_structure_type(), ''],
-                               'stf_type': [stf_type, ''], 'sigma_y1': [sigma_y1_new, 'MPa'],
-                               'sigma_y2': [sigma_y2_new, 'MPa'], 'sigma_x': [sigma_x_new, 'MPa'],
-                               'tau_xy': [tau_xy_new, 'MPa'], 'plate_kpp': [init_obj.get_kpp(), ''],
-                               'stf_kps': [init_obj.get_kps(), ''], 'stf_km1': [init_obj.get_km1(), ''],
-                               'stf_km2': [init_obj.get_km2(), ''], 'stf_km3': [init_obj.get_km3(), '']}
+                   'spacing': [x[0], 'm'], 'plate_thk': [x[1], 'm'], 'stf_web_height': [x[2], 'm'],
+                   'stf_web_thk': [x[3], 'm'], 'stf_flange_width': [x[4], 'm'],
+                   'stf_flange_thk': [x[5], 'm'], 'structure_type': [init_obj.get_structure_type(), ''],
+                   'stf_type': [stf_type, ''], 'sigma_y1': [sigma_y1_new, 'MPa'],
+                   'sigma_y2': [sigma_y2_new, 'MPa'], 'sigma_x': [sigma_x_new, 'MPa'],
+                   'tau_xy': [tau_xy_new, 'MPa'], 'plate_kpp': [init_obj.get_kpp(), ''],
+                   'stf_kps': [init_obj.get_kps(), ''], 'stf_km1': [init_obj.get_km1(), ''],
+                   'stf_km2': [init_obj.get_km2(), ''], 'stf_km3': [init_obj.get_km3(), ''],
+                 'structure_types': [init_obj.get_structure_types(), ''],
+                 'zstar_optimization': [init_obj.get_z_opt(), ''],
+                 'puls buckling method': [init_obj.get_puls_method(), ''],
+                 'puls boundary': [init_obj.get_puls_boundary(), ''],
+                 'puls stiffener end': [init_obj.get_puls_stf_end(), ''],
+                 'puls sp or up': [init_obj.get_puls_sp_or_up(), ''],
+                 'puls up boundary': [init_obj.get_puls_up_boundary(), ''],
+                 }
+
+
     if fat_dict == None:
         return calc.Structure(main_dict)
 
@@ -800,20 +844,26 @@ def stress_scaling_area(sigma_old,a_old,a_new):
 
     if a_new <= a_old: #decreasing the thickness
         sigma_new = sigma_old*(a_old/(a_old-abs((a_old-a_new))))
-        assert sigma_new >= sigma_old, 'ERROR no stress increase: \n' \
-                                      't_old '+str(a_old)+' sigma_old '+str(sigma_old)+ \
-                                      '\nt_new '+str(a_new)+' sigma_new '+str(sigma_new)
+        # assert sigma_new >= sigma_old, 'ERROR no stress increase: \n' \
+        #                               't_old '+str(a_old)+' sigma_old '+str(sigma_old)+ \
+        #                               '\nt_new '+str(a_new)+' sigma_new '+str(sigma_new)
     else: #increasing the thickness
         sigma_new = sigma_old*(a_old/(a_old+0.5*abs((a_old-a_new))))
-        assert sigma_new <= sigma_old, 'ERROR no stress reduction: \n' \
-                                      't_old '+str(a_old)+' sigma_old '+str(sigma_old)+ \
-                                      '\nt_new '+str(a_new)+' sigma_new '+str(sigma_new)
+        # assert sigma_new <= sigma_old, 'ERROR no stress reduction: \n' \
+        #                               't_old '+str(a_old)+' sigma_old '+str(sigma_old)+ \
+        #                               '\nt_new '+str(a_new)+' sigma_new '+str(sigma_new)
     #print('a_old', a_old, 'sigma_old', sigma_old, '|', 'a_new', a_new, 'sigma_new',sigma_new)
     return sigma_new
 
+def x_to_string(x):
+    ret = ''
+    for val in x:
+        ret += str(val) + '_'
+    return ret
+
 def get_filtered_results(iterable_all,init_stuc_obj,lat_press,init_filter_weight,side='p',
-                         chk=(True,True,True,True,True,True,True),fat_dict = None, fat_press = None,
-                         slamming_press=None, processes = None):
+                         chk=(True,True,True,True,True,True,True, False),fat_dict = None, fat_press = None,
+                         slamming_press=None, processes = None, puls_sheet = None, puls_acceptance = 0.87):
     '''
     Using multiprocessing to return list of applicable results.
 
@@ -825,9 +875,33 @@ def get_filtered_results(iterable_all,init_stuc_obj,lat_press,init_filter_weight
     :param chk:
     :return:
     '''
-    #print('Init filter weigh', init_filter_weight)
+    #print('Init filter weight', init_filter_weight)
+    '''
+    x,obj,lat_press,init_weight,side='p',chk=(True,True,True,True, True, True, True, False),
+                        fat_dict = None, fat_press = None, slamming_press = 0, , puls_results = None, print_result = False
+    '''
+    if chk[7]:
+        # PULS to be used.
+        #calc.PULSpanel
+        '''
+        dict_to_run[line_given] = self._line_to_struc[line_given][1].get_puls_input()
+        dict_to_run[line_given]['Identification'] = line_given
+        dict_to_run[line_given]['Pressure (fixed)'] = self.get_highest_pressure(line_given)['normal'] / 1e6
+        '''
+        dict_to_run = {}
+        for x in iterable_all:
+            x_id = x_to_string(x)
+            calc_object = create_new_calc_obj(init_stuc_obj, x, fat_dict)
+            dict_to_run[x_id] = calc_object[0].get_puls_input()
+            dict_to_run[x_id]['Identification'] = x_id
+            dict_to_run[x_id]['Pressure (fixed)'] = lat_press/1000 # PULS sheet to have pressure in MPa
 
-    iter_var = ((item,init_stuc_obj,lat_press,init_filter_weight,side,chk,fat_dict,fat_press,slamming_press)
+        PULSrun = calc.PULSpanel(dict_to_run, puls_sheet_location=puls_sheet, puls_acceptance=puls_acceptance)
+        PULSrun.run_all()
+    else:
+        PULSrun = None
+
+    iter_var = ((item,init_stuc_obj,lat_press,init_filter_weight,side,chk,fat_dict,fat_press,slamming_press, PULSrun)
                 for item in iterable_all)
     #res_pre = it.starmap(any_constraints_all, iter_var)
     if processes is None:
@@ -905,7 +979,8 @@ def any_get_all_combs(min_var, max_var,deltas, init_weight = float('inf'), prede
 
     return comb
 
-def get_initial_weight(obj,lat_press,min_var,max_var,deltas,trials,fat_dict,fat_press, predefined_stiffener_iter):
+def get_initial_weight(obj,lat_press,min_var,max_var,deltas,trials,fat_dict,fat_press, predefined_stiffener_iter,
+                       slamming_press):
     '''
     Return a guess of the initial weight used to filter the constraints.
     Only aim is to reduce running time of the algorithm.
@@ -921,7 +996,7 @@ def get_initial_weight(obj,lat_press,min_var,max_var,deltas,trials,fat_dict,fat_
 
     for x in trial_selection:
         if any_constraints_all(x=x,obj=obj,lat_press=lat_press,init_weight=min_weight,
-                               fat_dict=fat_dict,fat_press = fat_press)[0]:
+                               fat_dict=fat_dict,fat_press = fat_press,slamming_press=slamming_press)[0]:
             current_weight = calc_weight(x)
             if current_weight < min_weight:
                 min_weight = current_weight
@@ -1038,28 +1113,30 @@ def plot_optimization_results(results, multiple = False):
 
 if __name__ == '__main__':
     import ANYstructure.example_data as ex
-    obj_dict = ex.obj_dict
-    fat_obj = ex.get_fatigue_object()
-    fp = ex.get_fatigue_pressures()
+    obj_dict = ex.obj_dict_sec_error
+    fat_obj = ex.get_fatigue_object_problematic()
+    fp = ex.get_fatigue_pressures_problematic()
     fat_press = ((fp['p_ext']['loaded'],fp['p_ext']['ballast'],fp['p_ext']['part']),
                  (fp['p_int']['loaded'],fp['p_int']['ballast'],fp['p_int']['part']))
     x0 = [obj_dict['spacing'][0], obj_dict['plate_thk'][0], obj_dict['stf_web_height'][0], obj_dict['stf_web_thk'][0],
           obj_dict['stf_flange_width'][0], obj_dict['stf_flange_thk'][0], obj_dict['span'][0], 10]
 
     obj = calc.Structure(obj_dict)
-    lat_press = 271.124
+    lat_press = 427.235
     calc_object = calc.CalcScantlings(obj_dict)
-    lower_bounds = np.array([0.6, 0.01, 0.3, 0.01, 0.1, 0.01, 3.5, 10])
-    upper_bounds = np.array([0.8, 0.02, 0.5, 0.02, 0.22, 0.03, 3.5, 10])
-    deltas = np.array([0.025, 0.0025, 0.025, 0.0025, 0.025, 0.0025])
+    lower_bounds = np.array([0.875, 0.012, 0.3, 0.012, 0.1, 0.012, 3.5, 10])
+    upper_bounds = np.array([0.875, 0.025, 0.5, 0.018, 0.2, 0.03, 3.5, 10])
+    deltas = np.array([0.025, 0.001, 0.01, 0.001, 0.01, 0.001])
 
 
     t1 = time.time()
     #
-    # results = run_optmizataion(obj, lower_bounds,upper_bounds, lat_press, deltas, algorithm='anysmart',
-    #                            fatigue_obj=fat_obj, fat_press_ext_int=fat_press, use_weight_filter=True,
-    #                            predefined_stiffener_iter=hlp.helper_read_section_file('sections.csv', obj=obj))
-    # # print(results)
+    results = run_optmizataion(obj, lower_bounds,upper_bounds, lat_press, deltas, algorithm='anysmart',
+                               fatigue_obj=fat_obj, fat_press_ext_int=fat_press, use_weight_filter=True)
+
+    print(results[1])
+    print(results[1].get_dnv_min_section_modulus(lat_press))
+    print(min([round(results[1].get_section_modulus()[0], 5), round(results[1].get_section_modulus()[1], 5)]))
 
     # t1 = time.time()
     # check_ok_array, check_array, section_array = list(), list(), list()
@@ -1124,21 +1201,21 @@ if __name__ == '__main__':
     #     results = run_optmizataion(obj, upper_bounds, lower_bounds, lat_press, deltas, algorithm='anysmart',
     #                            fatigue_obj=fat_obj, fat_press_ext_int=fat_press, pso_options=pso_options)[0]
     #     print('Swarm size', swarm_size, 'running time', time.time()-t1, results.get_one_line_string())
-    fat_press_ext_int = list()
-    for pressure in ex.get_geo_opt_fat_press():
-        fat_press_ext_int.append(((pressure['p_ext']['loaded'], pressure['p_ext']['ballast'],
-                                   pressure['p_ext']['part']),
-                                  (pressure['p_int']['loaded'], pressure['p_int']['ballast'],
-                                   pressure['p_int']['part'])))
-
-    opt_girder_prop = (0.018, 0.25,0.015, 0,0, 1.1,0.9)
-
-    results = run_optmizataion(ex.get_geo_opt_object(), lower_bounds, upper_bounds, ex.get_geo_opt_presure(), deltas,
-                               is_geometric=True, fatigue_obj=ex.get_geo_opt_fatigue(),
-                               fat_press_ext_int=fat_press_ext_int,
-                               slamming_press=ex.get_geo_opt_slamming_none(), load_pre=False,
-                               opt_girder_prop= opt_girder_prop,
-                               min_max_span=(1,12), tot_len=12)
+    # fat_press_ext_int = list()
+    # for pressure in ex.get_geo_opt_fat_press():
+    #     fat_press_ext_int.append(((pressure['p_ext']['loaded'], pressure['p_ext']['ballast'],
+    #                                pressure['p_ext']['part']),
+    #                               (pressure['p_int']['loaded'], pressure['p_int']['ballast'],
+    #                                pressure['p_int']['part'])))
+    #
+    # opt_girder_prop = (0.018, 0.25,0.015, 0,0, 1.1,0.9)
+    #
+    # results = run_optmizataion(ex.get_geo_opt_object(), lower_bounds, upper_bounds, ex.get_geo_opt_presure(), deltas,
+    #                            is_geometric=True, fatigue_obj=ex.get_geo_opt_fatigue(),
+    #                            fat_press_ext_int=fat_press_ext_int,
+    #                            slamming_press=ex.get_geo_opt_slamming_none(), load_pre=False,
+    #                            opt_girder_prop= opt_girder_prop,
+    #                            min_max_span=(1,12), tot_len=12)
 
     # import pickle
     # with open('geo_opt_2.pickle', 'rb') as file:
