@@ -54,6 +54,10 @@ class CreateOptGeoWindow():
         self._frame.geometry('1800x950')
         self._frame.grab_set()
         self._canvas_origo = (50, 720 - 50)
+        
+        self._canvas_base_origo = self._canvas_origo
+        self._canvas_draw_origo = list(self._canvas_base_origo)
+        self._previous_drag_mouse = list(self._canvas_draw_origo)
 
         self._active_lines = []
         self._add_to_lines = True
@@ -217,11 +221,11 @@ class CreateOptGeoWindow():
                                                                                      y=start_y - 0.6 * dy)
         tk.Label(self._frame, text='Flange thk. [mm]', font='Verdana 7 bold').place(x=start_x + 6.97 * dx,
                                                                                     y=start_y - 0.6 * dy)
-        tk.Label(self._frame, text='Estimated running time for algorithm: ',
+        tk.Label(self._frame, text='Estimated running time for algorithm not calculated.',
                  font='Verdana 9 bold').place(x=start_x, y=start_y + 2.8 * dy)
-        self._runnig_time_label = tk.Label(self._frame, text='', font='Verdana 9 bold')
-        self._runnig_time_label.place(x=start_x + 2.7 * dx, y=start_y + 2.8 * dy)
-        tk.Label(self._frame, text='seconds ', font='Verdana 9 bold').place(x=start_x + 3.3 * dx, y=start_y + 2.8 * dy)
+        # self._runnig_time_label = tk.Label(self._frame, text='', font='Verdana 9 bold')
+        # self._runnig_time_label.place(x=start_x + 2.7 * dx, y=start_y + 2.8 * dy)
+        # tk.Label(self._frame, text='seconds ', font='Verdana 9 bold').place(x=start_x + 3.3 * dx, y=start_y + 2.8 * dy)
         self._result_label = tk.Label(self._frame, text='', font='Verdana 9 bold')
         self._result_label.place(x=start_x, y=start_y + 3.4 * dy)
 
@@ -308,7 +312,7 @@ class CreateOptGeoWindow():
         # self._new_algorithm.trace('w', self.update_running_time)
 
         self.running_time_per_item = 4e-05
-        self._runnig_time_label.config(text=str(self.get_running_time()))
+        #self._runnig_time_label.config(text=str(self.get_running_time()))
         self._ent_algorithm.place(x=start_x + dx * 10, y=start_y + dy)
         self.algorithm_random_label = tk.Label(self._frame, text='Number of trials')
         tk.Button(self._frame, text='algorith information', command=self.algorithm_info, bg='white') \
@@ -503,7 +507,7 @@ class CreateOptGeoWindow():
         contraints = (self._new_check_sec_mod.get(), self._new_check_min_pl_thk.get(),
                       self._new_check_shear_area.get(), self._new_check_buckling.get(),
                       self._new_check_fatigue.get(), self._new_check_slamming.get(),
-                      self._new_check_local_buckling.get())
+                      self._new_check_local_buckling.get(), False)
 
         self.pso_parameters = (self._new_swarm_size.get(), self._new_omega.get(), self._new_phip.get(),
                                self._new_phig.get(),self._new_maxiter.get(), self._new_minstep.get(),
@@ -546,15 +550,19 @@ class CreateOptGeoWindow():
                 gotten_lat_press = self.app.get_highest_pressure(closet_line)
                 lateral_press.append(gotten_lat_press['normal'] / 1000)
                 slamming_press.append(gotten_lat_press['slamming'])
-                try:
-                    fat_press_single = self.app.get_fatigue_pressures(line, fat_obj_single.get_accelerations())
+                if fat_obj_single is not None:
+                    fat_press_single = self.app.get_fatigue_pressures(closet_line, fat_obj_single.get_accelerations())
                     fat_press_tuple = ((fat_press_single['p_ext']['loaded'], fat_press_single['p_ext']['ballast'],
                                         fat_press_single['p_ext']['part']),
                                        (fat_press_single['p_int']['loaded'], fat_press_single['p_int']['ballast'],
                                         fat_press_single['p_int']['part']))
                     fat_press_ext_int.append(fat_press_tuple)
-                except AttributeError:
-                    fat_press_ext_int.append(None)
+                else:
+                    fat_press_ext_int.append(((0, 0, 0), (0, 0,0)))
+
+                # except AttributeError:
+                #     print('AttributeError')
+                #     fat_press_ext_int.append(None)
         if broke:
             messagebox.showinfo(title='Selection error.',
                                 message='This field cannot be subdivided or there are no loads. Error.')
@@ -807,10 +815,11 @@ class CreateOptGeoWindow():
         Estimate the running time of the algorithm.
         :return:
         '''
-        try:
-            self._runnig_time_label.config(text=str(self.get_running_time()))
-        except ZeroDivisionError:
-            pass  # _tkinter.TclError: pass
+        pass
+        # try:
+        #     self._runnig_time_label.config(text=str(self.get_running_time()))
+        # except ZeroDivisionError:
+        #     pass  # _tkinter.TclError: pass
 
     def get_upper_bounds(self):
         '''
@@ -887,7 +896,7 @@ class CreateOptGeoWindow():
                                               ctr_x + m * init_obj.get_web_thk() / 2,
                                               ctr_y - m * (init_obj.get_web_h() + init_obj.get_pl_thk())
                                               , fill=init_color, stipple=init_stipple)
-            if init_obj.get_stiffener_type() != 'L':
+            if init_obj.get_stiffener_type() not in ['L', 'L-bulb']:
                 self._canvas_opt.create_rectangle(ctr_x - m * init_obj.get_fl_w() / 2,
                                                   ctr_y - m * (init_obj.get_pl_thk() + init_obj.get_web_h()),
                                                   ctr_x + m * init_obj.get_fl_w() / 2,
@@ -914,7 +923,7 @@ class CreateOptGeoWindow():
                                               ctr_y - m * (
                                                   opt_obj.get_web_h() + opt_obj.get_pl_thk())
                                               , fill=opt_color, stipple=opt_stippe)
-            if init_obj.get_stiffener_type() != 'L':
+            if init_obj.get_stiffener_type() not in ['L', 'L-bulb']:
                 self._canvas_opt.create_rectangle(ctr_x - m * opt_obj.get_fl_w() / 2, ctr_y
                                                   - m * (
                                                       opt_obj.get_pl_thk() + opt_obj.get_web_h()),
@@ -974,12 +983,12 @@ class CreateOptGeoWindow():
         if opt_results is None:
             # stippled lines and text.
 
-            self._canvas_select.create_line(self._canvas_origo[0], 0, self._canvas_origo[0], self._select_canvas_dim[1],
+            self._canvas_select.create_line(self._canvas_draw_origo[0], 0, self._canvas_draw_origo[0], self._select_canvas_dim[1],
                                             stipple='gray50')
-            self._canvas_select.create_line(0, self._canvas_origo[1], self._select_canvas_dim[0], self._canvas_origo[1],
+            self._canvas_select.create_line(0, self._canvas_draw_origo[1], self._select_canvas_dim[0], self._canvas_draw_origo[1],
                                             stipple='gray50')
-            self._canvas_select.create_text(self._canvas_origo[0] - 30,
-                                            self._canvas_origo[1] + 20, text='(0,0)',
+            self._canvas_select.create_text(self._canvas_draw_origo[0] - 30,
+                                            self._canvas_draw_origo[1] + 20, text='(0,0)',
                                             font='Text 10')
             self._canvas_select.create_text([700, 50],
                                             text='How to:\n'
@@ -1287,8 +1296,8 @@ class CreateOptGeoWindow():
         :param point_no:
         :return:
         '''
-        point_coord_x = self._canvas_origo[0] + self._point_dict[point_no][0] * self._canvas_scale
-        point_coord_y = self._canvas_origo[1] - self._point_dict[point_no][1] * self._canvas_scale
+        point_coord_x = self._canvas_draw_origo[0] + self._point_dict[point_no][0]* self._canvas_scale
+        point_coord_y = self._canvas_draw_origo[1] - self._point_dict[point_no][1]* self._canvas_scale
 
         return [point_coord_x, point_coord_y]
 
@@ -1298,8 +1307,8 @@ class CreateOptGeoWindow():
         :param point_no:
         :return:
         '''
-        point_coord_x = self._canvas_origo[0] + coord[0] * self._canvas_scale
-        point_coord_y = self._canvas_origo[1] - coord[1] * self._canvas_scale
+        point_coord_x = self._canvas_draw_origo[0] + coord[0] * self._canvas_scale
+        point_coord_y = self._canvas_draw_origo[1] - coord[1] * self._canvas_scale
 
         return [point_coord_x, point_coord_y]
 
@@ -1317,6 +1326,9 @@ class CreateOptGeoWindow():
         self._frame.bind('<Control_L>', self.ctrl_pressed)
         self._frame.bind('<Control_R>', self.ctrl_pressed)
 
+        self._frame.bind("<MouseWheel>", self.mouse_scroll)
+        self._frame.bind("<B2-Motion>", self.button_2_click_and_drag)
+
     def shift_pressed(self, event=None):
         '''
         Event is executed when shift key pressed.
@@ -1337,6 +1349,7 @@ class CreateOptGeoWindow():
         When clicking the right button, this method is called.
         method is referenced in
         '''
+        self._previous_drag_mouse = [event.x, event.y]
         if type(self._geo_results) is not list():
             if self._geo_results is not None:
                 return
@@ -1369,6 +1382,7 @@ class CreateOptGeoWindow():
         :param evnet:
         :return:
         '''
+        self._previous_drag_mouse = [event.x, event.y]
         self._active_lines = []
         self._active_points = []
         self.draw_select_canvas()
@@ -1379,6 +1393,10 @@ class CreateOptGeoWindow():
         :param evnet:
         :return:
         '''
+        self._previous_drag_mouse = [event.x, event.y]
+
+        if self._opt_resutls =={}:
+            return
         click_x = self._canvas_select.winfo_pointerx() - self._canvas_select.winfo_rootx()
         click_y = self._canvas_select.winfo_pointery() - self._canvas_select.winfo_rooty()
 
@@ -1496,6 +1514,20 @@ class CreateOptGeoWindow():
             self._ent_option_field = tk.OptionMenu(self._frame, self._new_option_panel, *to_add)
             self._ent_option_field.place(x=self._options_panels_place[0], y=self._options_panels_place[1])
 
+    def mouse_scroll(self,event):
+        self._canvas_scale +=  event.delta/50
+        self._canvas_scale = 0 if self._canvas_scale < 0 else self._canvas_scale
+
+        self.draw_select_canvas()
+
+    def button_2_click_and_drag(self,event):
+
+        self._canvas_draw_origo = (self._canvas_draw_origo[0]-(self._previous_drag_mouse[0]-event.x),
+                                  self._canvas_draw_origo[1]-(self._previous_drag_mouse[1]-event.y))
+
+        self._previous_drag_mouse = (event.x,event.y)
+        self.draw_select_canvas()
+
 if __name__ == '__main__':
     root = tk.Tk()
     my_app = CreateOptGeoWindow(master=root)
